==> khttrack-0.10.tar.bz2: khttrack-0.10/khttrack/khttrackmirror.cpp <==
/***************************************************************************
                          khttrackmirror.cpp  -  description
                             -------------------
    begin                : Wed Jul 3 2002
    copyright            : (C) 2002 by Stphane Chapeau
    email                : nuscly@ifrance.com
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <stdio.h>
#include <string.h>
#include <pthread.h> // pthread
#include <stdlib.h> // exit
#include <klocale.h>  // i18n
#include <qmessagebox.h>

#include "khttrackmirror.h"

#include "../lib/src/httrack-library.h"

#include "libwrapper.h"

extern KhttrackMirror *kMirrorViewGlobal;

extern char httrackCmd[500][1024] ;

extern int arretbrutal ;

KhttrackMirror::KhttrackMirror(QWidget *parent, const char *name ) : mirrorView(parent,name) {
}


KhttrackMirror::~KhttrackMirror(){
}


/** Initilialise et lance le moteur */
void KhttrackMirror::launch(){

 pthread_t threads[1];  //  pth_khttrack_main
  int rc ;


  kMirrorViewGlobal->show();

//  for (int i=0; i< 10 ; i++ )
//      printf("\nhttrackCmd[%i]=%s",i,httrackCmd[i]);


  rc = pthread_create(&threads[0], NULL, pth_khttrack_main, (void *)0);
  if (rc){
     printf("ERROR; return code from pthread_create() is %d\n", rc);
     exit(-1);
  }

}

/* Hide or show action list */
void KhttrackMirror::action_show()
{
   if (actions->isChecked() )
      Frame3->show();
   else
      Frame3->hide();

}

void KhttrackMirror::action_cancel()
{

   //pthread_cancel(threads[0]);
   arretbrutal = 0;
   hide();

}

char* KhttrackMirror::Q1()
{

/*
   switch( QMessageBox::information( this, "Q1",
       "The document has been changed since "
      "the last save.",
      "Save Now", "Cancel", "Leave Anyway",
      0, 1 ) ) {
    case 0:

  qWarning("accept();");
  break;
    case 1:
    default: // just for sanity
  qWarning("ignore();");
  break;
    case 2:
  qWarning("accept();");
  break;
    }
*/
  return "Y" ;

}

char* KhttrackMirror::Q2()
{

/*


    QMessageBox mb( "Application name here",
                    "Saving the file will overwrite the old file on disk.\n"
                    "Do you really want to save?",
                    QMessageBox::Information,
                    QMessageBox::Yes | QMessageBox::Default,
                    QMessageBox::No,
                    QMessageBox::Cancel | QMessageBox::Escape );
    mb.setButtonText( QMessageBox::Yes, "Save" );
    mb.setButtonText( QMessageBox::No, "Don't Save" );
    switch( mb.exec() ) {
        case QMessageBox::Yes:
            // save and exit
            break;
        case QMessageBox::No:
            // exit without saving
            break;
        case QMessageBox::Cancel:
            // don't save and don't exit
            break;
    }
*/
/*
  QMessageBox::information( this, "Cancel",
                            "Arreter le downlod" );

    switch( QMessageBox::information( this, "Q2",
       "The document has been changed since "
      "the last save.",
      "Save Now", "Cancel", "Leave Anyway",
      0, 1 ) ) {
    case 0:

  qWarning("accept();");
  break;
    case 1:
    default: // just for sanity
  qWarning("ignore();");
  break;
    case 2:
  qWarning("accept();");
  break;
    }
*/
  return "Y" ;

}

char* KhttrackMirror::Q3()
{
/*    switch( QMessageBox::information( this, "Q3",
       "The document has been changed since "
      "the last save.",
      "Save Now", "Cancel", "Leave Anyway",
      0, 1 ) ) {
    case 0:

  qWarning("accept();");
  break;
    case 1:
    default: // just for sanity
  qWarning("ignore();");
  break;
    case 2:
  qWarning("accept();");
  break;
    }
*/
  return "Y" ;

}

/** Informe que le mirror est termin */
void KhttrackMirror::endMirror()
{

   pthread_t threads2[1];
   int rc2 ;

   hide();

   if ( ! (  (kMirrorViewGlobal->project->s_project.gene_action == 2) || (kMirrorViewGlobal->project->s_project.gene_action == 4) )  )
   {
      //pthread_cancel(threads[0]);

      rc2 = pthread_create(&threads2[0], NULL, pth_showlog, (void *)0);
      if (rc2)
      {
         printf("ERROR; return code from pthread_create() is %d\n", rc2);
         exit(-1);
      }
   }
   else
   {
       puts("Download terminated.");
   }


}

void *pth_showlog(void *threadid)
{
    char commande[1024] ;
    sprintf(commande, "kwrite %s/%s/hts-log.txt &\n",
    kMirrorViewGlobal->project->s_project.gene_projectPath,
    kMirrorViewGlobal->project->s_project.gene_projectName);
    printf(commande);
    system(commande);
    pthread_exit(NULL);
}

==> khttrack-0.11.tar.bz2: khttrack-0.11/khttrack/khttrackmirror.cpp <==
/***************************************************************************
                          khttrackmirror.cpp  -  description
                             -------------------
    begin                : Wed Jul 3 2002
    copyright            : (C) 2002 by Stphane Chapeau
    email                : nuscly-devel@laposte.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include <stdio.h>
#include <string.h>
#include <pthread.h> // pthread
#include <stdlib.h> // exit
#include <klocale.h>  // i18n
#include <qmessagebox.h>

#include "khttrackmirror.h"

#include "../lib/src/httrack-library.h"

#include "libwrapper.h"

extern KhttrackMirror *kMirrorViewGlobal;

extern char httrackCmd[500][1024] ;

extern int arretbrutal ;

KhttrackMirror::KhttrackMirror(QWidget *parent, const char *name ) : mirrorView(parent,name) {
}


KhttrackMirror::~KhttrackMirror(){
}


/** Initilialise et lance le moteur */
void KhttrackMirror::launch(){

 pthread_t threads[1];  //  pth_khttrack_main
  int rc ;


  kMirrorViewGlobal->show();

//  for (int i=0; i< 10 ; i++ )
//      printf("\nhttrackCmd[%i]=%s",i,httrackCmd[i]);


  rc = pthread_create(&threads[0], NULL, pth_khttrack_main, (void *)0);
  if (rc){
     printf("ERROR; return code from pthread_create() is %d\n", rc);
     exit(-1);
  }

}

/* Hide or show action list */
void KhttrackMirror::action_show()
{
   if (actions->isChecked() )
      Frame3->show();
   else
      Frame3->hide();

}

void KhttrackMirror::action_cancel()
{

   //pthread_cancel(threads[0]);
   arretbrutal = 0;
   hide();

}

char* KhttrackMirror::Q1()
{

/*
   switch( QMessageBox::information( this, "Q1",
       "The document has been changed since "
      "the last save.",
      "Save Now", "Cancel", "Leave Anyway",
      0, 1 ) ) {
    case 0:

  qWarning("accept();");
  break;
    case 1:
    default: // just for sanity
  qWarning("ignore();");
  break;
    case 2:
  qWarning("accept();");
  break;
    }
*/
  return "Y" ;

}

char* KhttrackMirror::Q2()
{

/*


    QMessageBox mb( "Application name here",
                    "Saving the file will overwrite the old file on disk.\n"
                    "Do you really want to save?",
                    QMessageBox::Information,
                    QMessageBox::Yes | QMessageBox::Default,
                    QMessageBox::No,
                    QMessageBox::Cancel | QMessageBox::Escape );
    mb.setButtonText( QMessageBox::Yes, "Save" );
    mb.setButtonText( QMessageBox::No, "Don't Save" );
    switch( mb.exec() ) {
        case QMessageBox::Yes:
            // save and exit
            break;
        case QMessageBox::No:
            // exit without saving
            break;
        case QMessageBox::Cancel:
            // don't save and don't exit
            break;
    }
*/
/*
  QMessageBox::information( this, "Cancel",
                            "Arreter le downlod" );

    switch( QMessageBox::information( this, "Q2",
       "The document has been changed since "
      "the last save.",
      "Save Now", "Cancel", "Leave Anyway",
      0, 1 ) ) {
    case 0:

  qWarning("accept();");
  break;
    case 1:
    default: // just for sanity
  qWarning("ignore();");
  break;
    case 2:
  qWarning("accept();");
  break;
    }
*/
  return "Y" ;

}

char* KhttrackMirror::Q3()
{
/*    switch( QMessageBox::information( this, "Q3",
       "The document has been changed since "
      "the last save.",
      "Save Now", "Cancel", "Leave Anyway",
      0, 1 ) ) {
    case 0:

  qWarning("accept();");
  break;
    case 1:
    default: // just for sanity
  qWarning("ignore();");
  break;
    case 2:
  qWarning("accept();");
  break;
    }
*/
  return "Y" ;

}

/** Informe que le mirror est termin */
void KhttrackMirror::endMirror()
{

   pthread_t threads2[1];
   int rc2 ;

   hide();

   if ( ! (  (kMirrorViewGlobal->project->s_project.gene_action == 2) || (kMirrorViewGlobal->project->s_project.gene_action == 4) )  )
   {
      //pthread_cancel(threads[0]);

      rc2 = pthread_create(&threads2[0], NULL, pth_showlog, (void *)0);
      if (rc2)
      {
         printf("ERROR; return code from pthread_create() is %d\n", rc2);
         exit(-1);
      }
   }
   else
   {
       puts("Download terminated.");
   }


}

void *pth_showlog(void *threadid)
{
    char commande[1024] ;
    sprintf(commande, "kwrite %s/%s/hts-log.txt &\n",
    kMirrorViewGlobal->project->s_project.gene_projectPath,
    kMirrorViewGlobal->project->s_project.gene_projectName);
    printf(commande);
    system(commande);
    pthread_exit(NULL);
}
